@@ -2,7 +2,7 @@ from . import _accessors as _a
 from . import _shapely as _s
 
 # prefer access to shapely computation
-_all = dict()
+_all = {}
 _all.update(_s.__dict__)
 _all.update(_a.__dict__)
 
