@@ -1,3 +1,5 @@
+import sys
+
 import geodatasets
 import geopandas as gpd
 import numpy as np
@@ -17,6 +19,7 @@ of the underlying data shall be tested in respective constructor test suites.
 """
 
 
+@pytest.mark.network
 class TestContiguity:
     def setup_method(self):
         self.gdf = gpd.read_file(geodatasets.get_path("nybb"))
@@ -140,7 +143,15 @@ class TestContiguity:
         assert pd.api.types.is_string_dtype(g._adjacency.index.dtypes["neighbor"])
         assert pd.api.types.is_numeric_dtype(g._adjacency.dtype)
 
+    def test_fuzzy_contiguity_kwargs(self):
+        g = graph.Graph.build_fuzzy_contiguity(self.gdf_str, resolution=2)
 
+        assert pd.api.types.is_string_dtype(g._adjacency.index.dtypes["focal"])
+        assert pd.api.types.is_string_dtype(g._adjacency.index.dtypes["neighbor"])
+        assert pd.api.types.is_numeric_dtype(g._adjacency.dtype)
+
+
+@pytest.mark.network
 class TestTriangulation:
     def setup_method(self):
         gdf = gpd.read_file(geodatasets.get_path("geoda liquor_stores")).explode(
@@ -208,6 +219,7 @@ class TestTriangulation:
         )
 
 
+@pytest.mark.network
 class TestKernel:
     def setup_method(self):
         self.gdf = gpd.read_file(geodatasets.get_path("geoda liquor_stores")).explode(
@@ -279,6 +291,7 @@ class TestKernel:
         assert pd.api.types.is_numeric_dtype(g._adjacency.dtype)
 
 
+@pytest.mark.network
 class TestDistanceBand:
     def setup_method(self):
         df = gpd.read_file(geodatasets.get_path("nybb"))
@@ -332,6 +345,7 @@ class TestDistanceBand:
         assert pd.api.types.is_numeric_dtype(g._adjacency.dtype)
 
 
+@pytest.mark.network
 class TestAdjacency:
     def setup_method(self):
         self.gdf = gpd.read_file(geodatasets.get_path("nybb"))
@@ -483,3 +497,65 @@ class TestMatching:
         assert pd.api.types.is_string_dtype(g._adjacency.index.dtypes["focal"])
         assert pd.api.types.is_string_dtype(g._adjacency.index.dtypes["neighbor"])
         assert pd.api.types.is_numeric_dtype(g._adjacency.dtype)
+
+
+@pytest.mark.network
+@pytest.mark.skipif(
+    sys.platform.startswith("win"), reason="pandana has dtype issues on windows"
+)
+class TestTravelNetwork:
+    def setup_method(self):
+        pandana = pytest.importorskip("pandana")
+        import pooch
+
+        self.net_path = pooch.retrieve(
+            "https://spatial-ucr.s3.amazonaws.com/osm/metro_networks_8k/17140.h5",
+            known_hash=None,
+        )
+        df = gpd.read_file(geodatasets.get_path("geoda cincinnati")).to_crs(4326)
+        self.df = df.set_geometry(df.centroid)
+        self.network = pandana.Network.from_hdf5(self.net_path)
+
+    def test_build_travel_network(self):
+        g = graph.Graph.build_travel_cost(self.df, self.network, 500)
+        assert_array_almost_equal(
+            g.adjacency.head(10).to_numpy(),
+            np.array(
+                [
+                    418.28601074,
+                    228.23899841,
+                    196.0269928,
+                    0.0,
+                    341.73498535,
+                    478.47799683,
+                    298.91699219,
+                    445.60501099,
+                    174.64199829,
+                    0.0,
+                ]
+            ),
+        )
+        assert g.n == self.df.shape[0]
+
+    def test_build_travel_network_kernel(self):
+        g = graph.Graph.build_travel_cost(
+            self.df, self.network, 500, kernel="triangular"
+        )
+        assert_array_almost_equal(
+            g.adjacency.head(10).to_numpy(),
+            np.array(
+                [
+                    0.16342798,
+                    0.543522,
+                    0.60794601,
+                    1.0,
+                    0.31653003,
+                    0.04304401,
+                    0.40216602,
+                    0.10878998,
+                    0.650716,
+                    1.0,
+                ]
+            ),
+        )
+        assert g.n == self.df.shape[0]
