@@ -199,7 +199,7 @@ class MatIO(fileio.FileIO):
             sio.savemat(self.file, {"WEIGHT": w})
             self.pos += 1
         else:
-            raise TypeError("Expected a PySAL weights object, got: %s." % (type(obj)))
+            raise TypeError(f"Expected a PySAL weights object, got: {type(obj)}.")
 
     def close(self):
         self.file.close()
