@@ -256,7 +256,7 @@ class MtxIO(fileio.FileIO):
             )
             self.pos += 1
         else:
-            raise TypeError("Expected a PySAL weights object, got: %s." % (type(obj)))
+            raise TypeError(f"Expected a PySAL weights object, got: {type(obj)}.")
 
     def close(self):
         self.file.close()
