@@ -22,7 +22,7 @@ class TesttestArcGISSwmIO:
         w = self.obj.read()
         assert w.n == 88
         assert w.mean_neighbors == 5.25
-        assert [1.0, 1.0, 1.0, 1.0] == list(w[1].values())
+        assert list(w[1].values()) == [1.0, 1.0, 1.0, 1.0]
 
     def test_seek(self):
         self.test_read()
