@@ -378,7 +378,7 @@ class Wk1IO(fileio.FileIO):
             self.pos += 1
 
         else:
-            raise TypeError("Expected a PySAL weights object, got: %s." % (type(obj)))
+            raise TypeError(f"Expected a PySAL weights object, got: {type(obj)}.")
 
     def close(self):
         self.file.close()
