@@ -8,7 +8,7 @@ from .. import adjtools as adj
 from ..util import lat2W
 
 
-class Test_Adjlist:
+class TestAdjlist:
     def setup_method(self):
         self.knownW = io.open(examples.get_path("columbus.gal")).read()
 
@@ -60,14 +60,14 @@ class Test_Adjlist:
                 alist_neighbors[idx] = []
             badgrid = weights.W(alist_neighbors)
             np.testing.assert_allclose(badgrid.sparse.toarray(), grid.sparse.toarray())
-        tuples = set([tuple(t) for t in alist[["focal", "neighbor"]].values])
+        tuples = {tuple(t) for t in alist[["focal", "neighbor"]].values}
         full_alist = grid.to_adjlist(drop_islands=True)
-        all_possible = set([tuple(t) for t in full_alist[["focal", "neighbor"]].values])
+        all_possible = {tuple(t) for t in full_alist[["focal", "neighbor"]].values}
         assert tuples.issubset(all_possible), (
             "the de-duped adjlist has links " "not in the duplicated adjlist."
         )
         complements = all_possible.difference(tuples)
-        reversed_complements = set([t[::-1] for t in complements])
+        reversed_complements = {t[::-1] for t in complements}
         assert reversed_complements == tuples, (
             "the remaining links in the duplicated"
             " adjlist are not the reverse of the links"
@@ -79,12 +79,12 @@ class Test_Adjlist:
         import geopandas
 
         df = geopandas.read_file(examples.get_path("columbus.dbf")).head()
-        W = weights.Queen.from_dataframe(df)
-        alist = adj.adjlist_apply(df[col], W=W, to_adjlist_kws=dict(drop_islands=True))
+        w = weights.Queen.from_dataframe(df)
+        alist = adj.adjlist_apply(df[col], W=w, to_adjlist_kws={"drop_islands": True})
         right_hovals = alist.groupby("focal").att_focal.unique()
         assert (right_hovals == df[col]).all()
         allpairs = np.subtract.outer(df[col].values, df[col].values)
-        flat_diffs = allpairs[W.sparse.toarray().astype(bool)]
+        flat_diffs = allpairs[w.sparse.toarray().astype(bool)]
         np.testing.assert_allclose(flat_diffs, alist["subtract"].values)
         return flat_diffs
 
@@ -95,15 +95,15 @@ class Test_Adjlist:
         import geopandas
 
         df = geopandas.read_file(examples.get_path("columbus.dbf")).head()
-        W = weights.Queen.from_dataframe(df)
+        w = weights.Queen.from_dataframe(df)
 
-        ssq = lambda x_y: np.sum((x_y[0] - x_y[1]) ** 2).item()
+        ssq = lambda x_y: np.sum((x_y[0] - x_y[1]) ** 2).item()  # noqa: E731
         ssq.__name__ = "sum_of_squares"
         alist = adj.adjlist_apply(
             df[["HOVAL", "CRIME", "INC"]],
-            W=W,
+            W=w,
             func=ssq,
-            to_adjlist_kws=dict(drop_islands=True),
+            to_adjlist_kws={"drop_islands": True},
         )
         known_ssq = [
             1301.1639302990804,
@@ -128,10 +128,10 @@ class Test_Adjlist:
     def test_map(self):
         atts = ["HOVAL", "CRIME", "INC"]
         df = geopandas.read_file(examples.get_path("columbus.dbf")).head()
-        W = weights.Queen.from_dataframe(df)
+        w = weights.Queen.from_dataframe(df)
         hoval, crime, inc = list(map(self.apply_and_compare_columbus, atts))
-        mapped = adj.adjlist_map(df[atts], W=W, to_adjlist_kws=dict(drop_islands=True))
-        for name, data in zip(atts, (hoval, crime, inc)):
+        mapped = adj.adjlist_map(df[atts], W=w, to_adjlist_kws={"drop_islands": True})
+        for name, data in zip(atts, (hoval, crime, inc), strict=True):
             np.testing.assert_allclose(
                 data, mapped["_".join(("subtract", name))].values
             )
@@ -154,28 +154,28 @@ class Test_Adjlist:
     def test_ids(self):
         df = geopandas.read_file(examples.get_path("columbus.dbf")).head()
         df["my_id"] = range(3, len(df) + 3)
-        W = weights.Queen.from_dataframe(df, ids="my_id")
-        W_adj = W.to_adjlist(drop_islands=True)
+        w = weights.Queen.from_dataframe(df, ids="my_id")
+        w_adj = w.to_adjlist(drop_islands=True)
         for i in range(3, 8):
-            assert i in W_adj.focal
-            assert i in W_adj.neighbor
-        for i in W_adj.focal:
+            assert i in w_adj.focal
+            assert i in w_adj.neighbor
+        for i in w_adj.focal:
             assert i in list(range(3, len(df) + 3))
-        for i in W_adj.neighbor:
+        for i in w_adj.neighbor:
             assert i in list(range(3, len(df) + 3))
 
     def test_str_ids(self):
         df = geopandas.read_file(examples.get_path("columbus.dbf")).head()
         snakes = ["mamba", "boa", "python", "rattlesnake", "cobra"]
         df["my_str_id"] = snakes
-        W = weights.Queen.from_dataframe(df, ids="my_str_id")
-        W_adj = W.to_adjlist(drop_islands=True)
+        w = weights.Queen.from_dataframe(df, ids="my_str_id")
+        w_adj = w.to_adjlist(drop_islands=True)
         for i in snakes:
-            (W_adj.focal == i).any()
-            (W_adj.neighbor == i).any()
-        for i in W_adj.focal:
+            (w_adj.focal == i).any()
+            (w_adj.neighbor == i).any()
+        for i in w_adj.focal:
             assert i in snakes
-        for i in W_adj.neighbor:
+        for i in w_adj.neighbor:
             assert i in snakes
 
     def test_lat2w(self):
